@@ -74,7 +74,7 @@ KCMMemory::KCMMemory(QWidget *parent, const QVariantList &) :
 	setButtons(Help);
 
 	QVBoxLayout *top = new QVBoxLayout(this);
-	top->setMargin(0);
+	top->setContentsMargins(0, 0, 0, 0);
 	top->setSpacing(1);
 
 	QGroupBox* informationGroup = initializeText();
@@ -197,7 +197,7 @@ QGroupBox* KCMMemory::initializeCharts() {
 
 	QHBoxLayout* chartsLayout = new QHBoxLayout(chartsGroup);
 	chartsLayout->setSpacing(1);
-	chartsLayout->setMargin(1);
+	chartsLayout->setContentsMargins(1, 1, 1, 1);
 
 	//chartsLayout->addStretch(1);
 
